@@ -41,24 +41,24 @@ SolarSystemComposite::SolarSystemComposite(SkyComposite *parent ) :
     m_Earth = new KSPlanet( I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
 
     m_Sun = new KSSun();
-    addComponent( new SolarSystemSingleComponent( this, m_Sun, Options::showSun ) );
+    addComponent( new SolarSystemSingleComponent( this, m_Sun, Options::showSun ), 2 );
     m_Moon = new KSMoon();
-    addComponent( new SolarSystemSingleComponent( this, m_Moon, Options::showMoon ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MERCURY ), Options::showMercury ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::VENUS ), Options::showVenus ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MARS ), Options::showMars ) );
+    addComponent( new SolarSystemSingleComponent( this, m_Moon, Options::showMoon ), 3 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MERCURY ), Options::showMercury ), 4 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::VENUS ), Options::showVenus ), 4 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::MARS ), Options::showMars ), 4 );
     SolarSystemSingleComponent *jup = new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::JUPITER ), Options::showJupiter );
-    addComponent( jup );
+    addComponent( jup, 4 );
     m_JupiterMoons = new PlanetMoonsComponent( this, jup, KSPlanetBase::JUPITER);
-    addComponent( m_JupiterMoons );
+    addComponent( m_JupiterMoons, 5 );
     SolarSystemSingleComponent *sat = new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::SATURN ), Options::showSaturn );
-    addComponent( sat );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::URANUS ), Options::showUranus ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::NEPTUNE ), Options::showNeptune ) );
+    addComponent( sat, 4 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::URANUS ), Options::showUranus ), 4 );
+    addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::NEPTUNE ), Options::showNeptune ), 4 );
     //addComponent( new SolarSystemSingleComponent( this, new KSPluto(), Options::showPluto ) );
 
-    addComponent( m_AsteroidsComponent = new AsteroidsComponent( this  ));
-    addComponent( m_CometsComponent    = new CometsComponent( this ));
+    addComponent( m_AsteroidsComponent = new AsteroidsComponent( this ), 7);
+    addComponent( m_CometsComponent    = new CometsComponent( this ), 7);
 }
 
 SolarSystemComposite::~SolarSystemComposite()
