@@ -444,6 +444,9 @@ public slots:
     void slotXplanetToFile();
 #endif
 
+    /** Render eyepiece view */
+    void slotEyepieceView();
+
     /** Zoom in one step. */
     void slotZoomIn();
 
@@ -663,6 +666,7 @@ private:
     QGraphicsScene *m_Scene;
 
     static SkyMap* pinstance;
+    const SkyPoint *m_rulerStartPoint; // Good to keep the original ruler start-point for purposes of dynamic_cast
 
 };
 
